@@ -5,7 +5,6 @@ Author: Niels Maeder
 """
 import pkg_resources
 
-from colorbymood.color import hex_from_dict  # type:ignore
-from colorbymood.window import Window  # type:ignore
+from colorbymood.window import Window  # type:ignore pylint:disable=E0611
 
 __version__ = pkg_resources.get_distribution("colorbymood").version
